Mailinglist Archive: opensuse-commit (1157 mails)
| < Previous | Next > |
commit kiwi
- From: root@xxxxxxxxxxxxxxx (h_root)
- Date: Wed, 17 Oct 2007 17:30:41 +0200
- Message-id: <20071017153041.C55E1678182@xxxxxxxxxxxxxxx>
Hello community,
here is the log from the commit of package kiwi
checked in at Wed Oct 17 17:30:41 CEST 2007.
--------
--- arch/i386/kiwi/kiwi.changes 2007-10-15 17:27:16.000000000 +0200
+++ /mounts/work_src_done/STABLE/kiwi/kiwi.changes 2007-10-17 16:23:18.014311000 +0200
@@ -1,0 +2,10 @@
+Tue Oct 16 15:18:38 CEST 2007 - ms@xxxxxxx
+
+- v1.74
+- fixed cdrom detection, wait for usb devices to settle (#333498)
+- make devices visible for udev by mount --move /dev /mnt/dev (#332678)
+- don't remove udev from boot images, related to (#332678)
+- added usb-uhci-hcd module for isoboot suse-10.3 (#334549)
+- removed runme_at_boot from oemboot linuxrc
+
+-------------------------------------------------------------------
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Other differences:
------------------
++++++ kiwi.spec ++++++
--- /var/tmp/diff_new_pack.v27303/_old 2007-10-17 17:29:50.000000000 +0200
+++ /var/tmp/diff_new_pack.v27303/_new 2007-10-17 17:29:50.000000000 +0200
@@ -1,5 +1,5 @@
#
-# spec file for package kiwi (Version 1.73)
+# spec file for package kiwi (Version 1.74)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
@@ -18,7 +18,7 @@
%endif
Requires: perl perl-XML-LibXML perl-libwww-perl screen coreutils
Summary: OpenSuSE - KIWI Image System
-Version: 1.73
+Version: 1.74
Release: 1
Group: System/Management
License: GPL v2 or later
@@ -329,6 +329,13 @@
%doc %{_datadir}/kiwi/image/oemboot/README
%{_datadir}/kiwi/image/oemboot/suse*
%changelog
+* Tue Oct 16 2007 - ms@xxxxxxx
+- v1.74
+- fixed cdrom detection, wait for usb devices to settle (#333498)
+- make devices visible for udev by mount --move /dev /mnt/dev (#332678)
+- don't remove udev from boot images, related to (#332678)
+- added usb-uhci-hcd module for isoboot suse-10.3 (#334549)
+- removed runme_at_boot from oemboot linuxrc
* Fri Oct 12 2007 - ms@xxxxxxx
- v1.73
- added setLogHumanReadable() function to convert the kiwi log
++++++ kiwi.tar.bz2 ++++++
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/kiwi.pl new/kiwi/kiwi.pl
--- old/kiwi/kiwi.pl 2007-10-14 09:13:13.000000000 +0200
+++ new/kiwi/kiwi.pl 2007-10-17 16:13:14.000000000 +0200
@@ -32,7 +32,7 @@
#============================================
# Globals (Version)
#--------------------------------------------
-our $Version = "1.73";
+our $Version = "1.74";
our $openSUSE = "http://software.opensuse.org/download/";
our $ConfigFile = "$ENV{'HOME'}/.kiwirc";
our $ConfigStatus = 0;
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/.revision new/kiwi/.revision
--- old/kiwi/.revision 2007-10-15 17:26:12.000000000 +0200
+++ new/kiwi/.revision 2007-10-17 16:19:11.000000000 +0200
@@ -1 +1 @@
-713
\ No newline at end of file
+718
\ No newline at end of file
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/isoboot/suse-10.3/config.xml new/kiwi/system/boot/isoboot/suse-10.3/config.xml
--- old/kiwi/system/boot/isoboot/suse-10.3/config.xml 2007-10-09 13:29:22.000000000 +0200
+++ new/kiwi/system/boot/isoboot/suse-10.3/config.xml 2007-10-17 16:12:58.000000000 +0200
@@ -16,6 +16,7 @@
<file name="usb/host/usb-uhci.ko"/>
<file name="usb/host/usb-ohci.ko"/>
<file name="usb/host/ehci-hcd.ko"/>
+ <file name="usb/host/uhci-hcd.ko"/>
<file name="usb/core/usbcore.ko"/>
<file name="usb/storage/usb-storage.ko"/>
</drivers>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/isoboot/suse-linuxrc new/kiwi/system/boot/isoboot/suse-linuxrc
--- old/kiwi/system/boot/isoboot/suse-linuxrc 2007-10-15 17:20:23.000000000 +0200
+++ new/kiwi/system/boot/isoboot/suse-linuxrc 2007-10-17 16:13:00.000000000 +0200
@@ -64,27 +64,31 @@
touch /lib/modules/*/modules.dep
#======================================
-# 4) Including required kernel modules
+# 4) run udevd
+#--------------------------------------
+udevStart
+
+#======================================
+# 5) Including required kernel modules
#--------------------------------------
probeDevices
if [ -z "$UNIONFS_CONFIG" ];then
Echo "Probing module: rd"
modprobe rd >/dev/null 2>&1
fi
-udevStart
#======================================
-# 5) Mount the CD device
+# 6) Mount the CD device
#--------------------------------------
CDMount
#======================================
-# 6) Load configuration
+# 7) Load configuration
#--------------------------------------
importFile < $LIVECD_CONFIG
#======================================
-# 7) Download RW part of the CD image
+# 8) Download RW part of the CD image
#--------------------------------------
IFS="," ; for i in $IMAGE;do
field=0
@@ -137,24 +141,24 @@
CDUmount
#======================================
-# 8) Get filesystem type
+# 9) Get filesystem type
#--------------------------------------
if [ -z "$UNIONFS_CONFIG" ];then
probeFileSystem $imageDevice
fi
#======================================
-# 9) Check for swap space
+# 10) Check for swap space
#--------------------------------------
swapSpace=`searchSwapSpace`
if [ ! -z "$swapSpace" ];then
#======================================
- # 9.1) use an existing swap partition
+ # 10.1) use an existing swap partition
#--------------------------------------
Echo "Found swap space on: $swapSpace"
else
#======================================
- # 9.1) use a swap file on a free part.
+ # 10.1) use a swap file on a free part.
#--------------------------------------
swapDevice=`searchDiskSpace`
if [ ! -z "$swapDevice" ];then
@@ -192,11 +196,11 @@
fi
#======================================
-# 10) Mount OS image to /mnt
+# 11) Mount OS image to /mnt
#--------------------------------------
if [ -z "$UNIONFS_CONFIG" ];then
#======================================
- # 10.1) mount RW part and CD to /mnt
+ # 11.1) mount RW part and CD to /mnt
#--------------------------------------
if ! mount $imageDevice /mnt &>/dev/null;then
systemException "Failed to mount RW root filesystem" "reboot"
@@ -204,7 +208,7 @@
mkdir -p /mnt/$LIVECD && mount $cddev /mnt/$LIVECD &>/dev/null
#======================================
- # 10.2) Create RO Link list
+ # 11.2) Create RO Link list
#--------------------------------------
cd /mnt
if [ ! -d $LIVECD/read-only-system ];then
@@ -228,7 +232,7 @@
cd /
else
#======================================
- # 10.1) mount CD to /mnt and unify
+ # 11.1) mount CD to /mnt and unify
#--------------------------------------
Echo "Mounting compressed unified tree..."
mkdir -p /mnt/$LIVECD && mount $cddev /mnt/$LIVECD &>/dev/null
@@ -239,7 +243,7 @@
fi
#======================================
-# 11) Create system dependant files
+# 12) Create system dependant files
#--------------------------------------
setupDefaultFstab /config
updateRootDeviceFstab /config $imageDevice
@@ -253,7 +257,7 @@
fi
#======================================
-# 12) copy system dependant files
+# 13) copy system dependant files
#--------------------------------------
cd /config
find . -type d | while read d ; do mkdir -p /mnt/$d ; done
@@ -262,29 +266,29 @@
rm -rf /config
#======================================
-# 13) setup real root device
+# 14) setup real root device
#--------------------------------------
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 14) umount system filesystems
+# 15) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 15) copy initrd files to image
+# 16) copy initrd files to image
#--------------------------------------
cp /preinit /mnt
cp /include /mnt
#======================================
-# 16) Activate new root
+# 17) Activate new root
#--------------------------------------
Echo "Activating Image: [$imageName]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -299,13 +303,14 @@
rm ./include
fi
#======================================
-# 17) Unmount initrd / system init
+# 18) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into Live CD System..."
echo "------------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / &>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/netboot/suse-linuxrc new/kiwi/system/boot/netboot/suse-linuxrc
--- old/kiwi/system/boot/netboot/suse-linuxrc 2007-10-11 15:39:06.000000000 +0200
+++ new/kiwi/system/boot/netboot/suse-linuxrc 2007-10-17 16:12:05.000000000 +0200
@@ -81,7 +81,12 @@
touch /lib/modules/*/modules.dep
#======================================
-# 3) Include proc/cmdline information
+# 3) run udevd
+#--------------------------------------
+udevStart
+
+#======================================
+# 4) Include proc/cmdline information
#--------------------------------------
includeKernelParameters
if [ ! -z $IMAGE ];then
@@ -94,7 +99,7 @@
fi
#======================================
-# 4) Obtain/load network module
+# 5) Obtain/load network module
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
loaded=0
@@ -117,14 +122,14 @@
fi
#======================================
-# 5) Setup network interface and DNS
+# 6) Setup network interface and DNS
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
setupNetwork
fi
#======================================
-# 6) get TFTP Server IP/name
+# 7) get TFTP Server IP/name
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
checkTFTP
@@ -140,7 +145,7 @@
fi
#======================================
-# 7) Load configuration
+# 8) Load configuration
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
CONFIG=/etc/config.netclient
@@ -234,13 +239,13 @@
fi
#======================================
-# (8) Load Device modules
+# 9) Load Device modules
#--------------------------------------
-probeDevices; udevStart
+probeDevices
export systemIntegrity="unknown"
#======================================
-# 9) Is this a diskful station
+# 10) Is this a diskful station
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if [ ! -z "$PART" ] && [ -z "$NFSROOT" ] && [ -z "$NBDROOT" ];then
@@ -299,7 +304,7 @@
fi
#======================================
-# 10) Download network client image
+# 11) Download network client image
#--------------------------------------
if [ -z "$NFSROOT" ] && [ -z "$NBDROOT" ];then
count=0
@@ -468,7 +473,7 @@
done
else
#======================================
- # 10.1) Check for NFS root
+ # 11.1) Check for NFS root
#--------------------------------------
if [ ! -z "$NFSROOT" ];then
IFS="," ; for i in $NFSROOT;do
@@ -486,7 +491,7 @@
systemIntegrity="clean"
fi
#======================================
- # 10.2) Check for NBD root
+ # 11.2) Check for NBD root
#--------------------------------------
if [ ! -z "$NBDROOT" ];then
if ! modprobe nbd;then
@@ -545,7 +550,7 @@
fi
#======================================
-# 11) Check for RELOAD_CONFIG
+# 12) Check for RELOAD_CONFIG
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test ! -z $DISK;then
@@ -557,14 +562,14 @@
fi
#======================================
-# 12) Mount OS image to /mnt
+# 13) Mount OS image to /mnt
#--------------------------------------
if ! mountSystem;then
systemException "Failed to mount root filesystem" "reboot"
fi
#======================================
-# 13) Import fixed configuration files
+# 14) Import fixed configuration files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -618,7 +623,7 @@
fi
#======================================
-# 14) send DHCP_RELEASE, reset cache
+# 15) send DHCP_RELEASE, reset cache
#--------------------------------------
if [ $LOCAL_BOOT = "no" ] && [ -z "$NFSROOT" ] && [ -z "$NBDROOT" ];then
if test $systemIntegrity = "clean";then
@@ -627,7 +632,7 @@
fi
#======================================
-# 15) Check if this is a split image
+# 16) Check if this is a split image
#--------------------------------------
if [ ! -z "$COMBINED_IMAGE" ] && [ -z "$NFSROOT" ] && [ -z "$NBDROOT" ]; then
READ_ONLY_SYSTEM=system
@@ -641,7 +646,7 @@
fi
#======================================
-# 16) check filesystem and kernels
+# 17) check filesystem and kernels
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -651,7 +656,7 @@
fi
#======================================
-# 17) make initrd available on unionfs
+# 18) make initrd available on unionfs
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test ! -z "$UNIONFS_CONFIG" && test $systemIntegrity = "clean";then
@@ -667,7 +672,7 @@
fi
#======================================
-# 18) Create system dependant files
+# 19) Create system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -683,7 +688,7 @@
fi
#======================================
-# 19) If image is new, notify
+# 20) If image is new, notify
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean"; then
@@ -711,7 +716,7 @@
fi
#======================================
-# 20) copy system dependant files
+# 21) copy system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -725,13 +730,12 @@
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 21) umount system filesystems
+# 22) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 22) copy initrd files to image
+# 23) copy initrd files to image
#--------------------------------------
if [ -f /image/loader/message ];then
mv /image/loader/message /mnt/boot
@@ -740,17 +744,18 @@
cp /include /mnt
#======================================
-# 23) check if reboot is required
+# 24) check if reboot is required
#--------------------------------------
kernelCheck /mnt
#======================================
-# 24) Activate new root
+# 25) Activate new root
#--------------------------------------
Echo "Activating Image: [$imageRootName]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -765,7 +770,7 @@
rm ./include
fi
#======================================
-# 25) reboot system if specified
+# 26) reboot system if specified
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test ! -z $REBOOT_IMAGE;then
@@ -774,13 +779,14 @@
fi
fi
#======================================
-# 26) Unmount initrd / system init
+# 27) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into final System..."
echo "----------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / 2>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/oemboot/suse-linuxrc new/kiwi/system/boot/oemboot/suse-linuxrc
--- old/kiwi/system/boot/oemboot/suse-linuxrc 2007-10-11 15:39:06.000000000 +0200
+++ new/kiwi/system/boot/oemboot/suse-linuxrc 2007-10-17 16:12:02.000000000 +0200
@@ -62,7 +62,12 @@
touch /lib/modules/*/modules.dep
#======================================
-# 3) Include proc/cmdline information
+# 3) run udevd
+#--------------------------------------
+udevStart
+
+#======================================
+# 4) Include proc/cmdline information
#--------------------------------------
includeKernelParameters
if [ ! -z $UNIONFS_CONFIG ];then
@@ -75,17 +80,16 @@
fi
#======================================
-# 4) Including required kernel modules
+# 5) Including required kernel modules
#--------------------------------------
probeDevices
for module in usb_storage sg sd_mod BusLogic;do
modprobe $module >/dev/null 2>&1
done
sleep 5
-udevStart
#======================================
-# 5) Search disks, prefer removable one
+# 6) Search disks, prefer removable one
#--------------------------------------
if [ ! -f $VMX_SYSTEM ];then
# /.../
@@ -157,15 +161,15 @@
fi
#======================================
-# 6) Check for vmx system
+# 7) Check for vmx system
#--------------------------------------
if [ -f $VMX_SYSTEM ];then
#======================================
- # 6.1) import vmx configuration file
+ # 7.1) import vmx configuration file
#--------------------------------------
importFile < $VMX_SYSTEM
#======================================
- # 6.2) check version of installed OS
+ # 7.2) check version of installed OS
#--------------------------------------
deviceRoot="$deviceDisk"2
probeFileSystem $deviceRoot
@@ -184,7 +188,7 @@
/sbin/reboot -f -i >/dev/null 2>&1
fi
#======================================
- # 6.3) mount CD/DVD/USB stick
+ # 7.3) mount CD/DVD/USB stick
#--------------------------------------
USBStickDevice
if [ $stickFound = 0 ];then
@@ -195,7 +199,7 @@
mkdir -p /cdrom && mount $stickDevice /cdrom
fi
#======================================
- # 6.4) install disk system
+ # 7.4) install disk system
#--------------------------------------
# /.../
# install virtual disk image from the CD/DVD onto the
@@ -238,15 +242,15 @@
rm -f /dev/compressed_image
fi
#======================================
- # 6.5) Umount the CD/DVD
+ # 7.5) Umount the CD/DVD
#--------------------------------------
umount /cdrom
#======================================
- # 6.6) reread partition table
+ # 7.6) reread partition table
#--------------------------------------
blockdev --rereadpt $deviceDisk
#======================================
- # 6.7) find new root partition
+ # 7.7) find new root partition
#--------------------------------------
unset UNIONFS_CONFIG
deviceRoot="$deviceDisk"2
@@ -260,7 +264,7 @@
export UNIONFS_CONFIG="$deviceDisk"3,"$deviceDisk"2,aufs
fi
#======================================
- # 6.8) Create md5 version info file
+ # 7.8) Create md5 version info file
#--------------------------------------
if ! mountSystem $deviceRoot;then
systemException \
@@ -282,7 +286,7 @@
echo "$atversion $md5sum" > $versionFile
umountSystem
#======================================
- # 6.9) reboot system
+ # 7.9) reboot system
#--------------------------------------
if [ $stickFound = 0 ];then
Echo "NOTE: Please remove the installation CD before reboot !"
@@ -296,7 +300,7 @@
fi
#======================================
-# 7) Probe filesystem of disk device
+# 8) Probe filesystem of disk device
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
probeFileSystem $deviceRoot
@@ -307,18 +311,18 @@
fi
fi
#======================================
-# 8) repartition the disk device
+# 9) repartition the disk device
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
#======================================
- # 8.1 calculate amount of swap space
+ # 9.1 calculate amount of swap space
#--------------------------------------
mem_size=`grep MemTotal: /proc/meminfo | tr -dc '[0-9]'`
swapsize=$(( $mem_size *2 / 1024 ))
Echo "Filesystem of root system is: $FSTYPE -> $deviceRoot"
if ! test "$FSTYPE" = "squashfs";then
#======================================
- # 8.2 write new partition table
+ # 9.2 write new partition table
#--------------------------------------
# /.../
# Explanation of the fdisk commands used within the
@@ -379,21 +383,21 @@
systemException "Failed to create partition table" "reboot"
fi
#======================================
- # 8.3 Update new device names
+ # 9.3 Update new device names
#--------------------------------------
export deviceRoot="$deviceDisk"2
export deviceSwap="$deviceDisk"1
export deviceHome="$deviceDisk"3
#======================================
- # 8.4 Activate swap space
+ # 9.4 Activate swap space
#--------------------------------------
Echo "Activating swap space on $deviceSwap"
if ! mkswap $deviceSwap >/dev/null 2>&1;then
systemException "Failed to create swap signature" "reboot"
fi
#======================================
- # 8.5 Create home file system
+ # 9.5 Create home file system
#--------------------------------------
Echo "Creating Home filesystem on $deviceHome"
if ! mke2fs -j -q $deviceHome >/dev/null 2>&1;then
@@ -401,7 +405,7 @@
fi
else
#======================================
- # 8.2 calculate end block - swapspace
+ # 9.2 calculate end block - swapspace
#--------------------------------------
swapXMBytes=$swapsize
diskXMBytes=`sfdisk -s $deviceDisk`
@@ -425,7 +429,7 @@
disk3MBytes=`expr $disk3MBytes - $swapXMBytes`
fi
#======================================
- # 8.3 write new partition table
+ # 9.3 write new partition table
#--------------------------------------
# /.../
# Explanation of the fdisk commands used within the
@@ -462,14 +466,14 @@
systemException "Failed to create partition table" "reboot"
fi
#======================================
- # 8.4 Update new device names
+ # 9.4 Update new device names
#--------------------------------------
export deviceBoot="$deviceDisk"1
export deviceRoot="$deviceDisk"2
export deviceSwap="$deviceDisk"4
#======================================
- # 8.5 Activate swap space
+ # 9.5 Activate swap space
#--------------------------------------
Echo "Activating swap space on $deviceSwap"
if ! mkswap $deviceSwap >/dev/null 2>&1;then
@@ -479,7 +483,7 @@
fi
#======================================
-# 9) Resize filesystem to full space
+# 10) Resize filesystem to full space
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test "$FSTYPE" = "squashfs";then
@@ -514,21 +518,21 @@
fi
#======================================
-# 10) Mount system
+# 11) Mount system
#--------------------------------------
if ! mountSystem $deviceRoot;then
systemException "Failed to mount root filesystem" "reboot"
fi
#======================================
-# 11) get installed kernels
+# 12) get installed kernels
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
kernelList /mnt
fi
#======================================
-# 12) Create system dependant files
+# 13) Create system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
setupDefaultFstab /config
@@ -545,7 +549,7 @@
fi
#======================================
-# 13) copy system dependant files
+# 14) copy system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
cd /config
@@ -556,18 +560,17 @@
fi
#======================================
-# 14) setup real root device
+# 15) setup real root device
#--------------------------------------
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 15) umount system filesystems
+# 16) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 16) copy initrd files to image
+# 17) copy initrd files to image
#--------------------------------------
if [ -f /image/loader/message ];then
mv /image/loader/message /mnt/boot
@@ -576,19 +579,13 @@
cp /include /mnt
#======================================
-# 17) Start YaST when booting final sys
-#--------------------------------------
-if [ $LOCAL_BOOT = "no" ];then
- touch /mnt/var/lib/YaST2/runme_at_boot >/dev/null 2>&1
-fi
-
-#======================================
# 18) Activate new root
#--------------------------------------
Echo "Activating Image: [$deviceDisk]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -604,13 +601,14 @@
fi
#======================================
-# 19) Unmount initrd / system init
+# 18) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into final System..."
echo "----------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / 2>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/usbboot/suse-linuxrc new/kiwi/system/boot/usbboot/suse-linuxrc
--- old/kiwi/system/boot/usbboot/suse-linuxrc 2007-10-11 15:39:06.000000000 +0200
+++ new/kiwi/system/boot/usbboot/suse-linuxrc 2007-10-17 16:12:05.000000000 +0200
@@ -55,21 +55,25 @@
touch /lib/modules/*/modules.dep
#======================================
-# 3) Including required kernel modules
+# 3) run udevd
+#--------------------------------------
+udevStart
+
+#======================================
+# 4) Including required kernel modules
#--------------------------------------
probeDevices
#======================================
-# 4) Load USB storage modules
+# 5) Load USB storage modules
#--------------------------------------
for module in usb_storage sg sd_mod;do
modprobe $module
done
sleep 5
-udevStart
#======================================
-# 5) Search USB stick device
+# 6) Search USB stick device
#--------------------------------------
USBStickDevice
if [ $stickFound = 0 ];then
@@ -79,7 +83,7 @@
fi
#======================================
-# 6) Probe filesystem of stick system
+# 7) Probe filesystem of stick system
#--------------------------------------
probeFileSystem $stickDevice
if [ $FSTYPE = "unknown" ];then
@@ -89,7 +93,7 @@
fi
#======================================
-# 7) Resize filesystem to full space
+# 8) Resize filesystem to full space
#--------------------------------------
Echo "Filesystem of stick system is: $FSTYPE -> $stickDevice"
if test "$FSTYPE" = "squashfs";then
@@ -112,14 +116,14 @@
fi
#======================================
-# 8) Mount USB stick (system)
+# 9) Mount USB stick (system)
#--------------------------------------
if ! mountSystem $stickDevice;then
systemException "Failed to mount root filesystem" "reboot"
fi
#======================================
-# 9) Create system dependant files
+# 10) Create system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -129,7 +133,7 @@
fi
#======================================
-# 10) copy system dependant files
+# 11) copy system dependant files
#--------------------------------------
if [ $LOCAL_BOOT = "no" ];then
if test $systemIntegrity = "clean";then
@@ -142,29 +146,29 @@
fi
#======================================
-# 11) setup real root device
+# 12) setup real root device
#--------------------------------------
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 12) umount system filesystems
+# 13) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 13) copy initrd files to image
+# 14) copy initrd files to image
#--------------------------------------
cp /preinit /mnt
cp /include /mnt
#======================================
-# 14) Activate new root
+# 15) Activate new root
#--------------------------------------
Echo "Activating Image: [$stickSerial on -> $stickDevice]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -179,13 +183,14 @@
rm ./include
fi
#======================================
-# 15) Unmount initrd / system init
+# 16) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into USB-Stick System..."
echo "--------------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / &>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/usbboot/suse-SLED10/config.xml new/kiwi/system/boot/usbboot/suse-SLED10/config.xml
--- old/kiwi/system/boot/usbboot/suse-SLED10/config.xml 2007-10-11 15:33:05.000000000 +0200
+++ new/kiwi/system/boot/usbboot/suse-SLED10/config.xml 2007-10-17 16:10:48.000000000 +0200
@@ -126,7 +126,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gzip"/>
<package name="gfxboot"/>
<package name="fribidi"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/usbboot/suse-SLED10-SP1/config.xml new/kiwi/system/boot/usbboot/suse-SLED10-SP1/config.xml
--- old/kiwi/system/boot/usbboot/suse-SLED10-SP1/config.xml 2007-10-11 15:33:07.000000000 +0200
+++ new/kiwi/system/boot/usbboot/suse-SLED10-SP1/config.xml 2007-10-17 16:10:49.000000000 +0200
@@ -126,7 +126,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gzip"/>
<package name="gfxboot"/>
<package name="fribidi"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-10.1/config.xml new/kiwi/system/boot/vmxboot/suse-10.1/config.xml
--- old/kiwi/system/boot/vmxboot/suse-10.1/config.xml 2007-10-11 15:33:19.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-10.1/config.xml 2007-10-17 16:12:56.000000000 +0200
@@ -113,7 +113,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-10.2/config.xml new/kiwi/system/boot/vmxboot/suse-10.2/config.xml
--- old/kiwi/system/boot/vmxboot/suse-10.2/config.xml 2007-10-11 15:33:20.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-10.2/config.xml 2007-10-17 16:12:57.000000000 +0200
@@ -113,7 +113,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-linuxrc new/kiwi/system/boot/vmxboot/suse-linuxrc
--- old/kiwi/system/boot/vmxboot/suse-linuxrc 2007-10-11 15:39:08.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-linuxrc 2007-10-17 16:12:57.000000000 +0200
@@ -102,17 +102,22 @@
touch /lib/modules/*/modules.dep
#======================================
-# 3) Including required kernel modules
+# 3) run udevd
#--------------------------------------
-probeDevices; udevStart
+udevStart
#======================================
-# 4) Mount VM (boot)
+# 4) Including required kernel modules
+#--------------------------------------
+probeDevices
+
+#======================================
+# 5) Mount VM (boot)
#--------------------------------------
VMFindSystem
#======================================
-# 5) Get filesystem type
+# 6) Get filesystem type
#--------------------------------------
probeFileSystem $imageRootDevice
if [ $FSTYPE = "unknown" ];then
@@ -122,7 +127,7 @@
fi
#======================================
-# 6) Resize filesystem to full space
+# 7) Resize filesystem to full space
#--------------------------------------
Echo "Filesystem of VMX system is: $FSTYPE -> $imageRootDevice"
if test "$FSTYPE" = "squashfs";then
@@ -148,19 +153,19 @@
fi
#======================================
-# 7) Mount VM (boot)
+# 8) Mount VM (boot)
#--------------------------------------
if ! mountSystem $imageRootDevice;then
systemException "Failed to mount root filesystem" "reboot"
fi
#======================================
-# 8) Get kernel list for local boot
+# 9) Get kernel list for local boot
#--------------------------------------
kernelList /mnt
#======================================
-# 9) Create system dependant files
+# 10) Create system dependant files
#--------------------------------------
setupDefaultFstab /config
updateRootDeviceFstab /config $imageRootDevice
@@ -168,7 +173,7 @@
setupKernelModules /config
#======================================
-# 10) copy system dependant files
+# 11) copy system dependant files
#--------------------------------------
cd /config
find . -type d | while read d ; do mkdir -p /mnt/$d ; done
@@ -177,18 +182,17 @@
rm -rf /config
#======================================
-# 11) setup real root device
+# 12) setup real root device
#--------------------------------------
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 12) umount system filesystems
+# 13) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 13) copy initrd files to image
+# 14) copy initrd files to image
#--------------------------------------
if [ -f /image/loader/message ];then
mv /image/loader/message /mnt/boot
@@ -197,12 +201,13 @@
cp /include /mnt
#======================================
-# 14) Activate new root
+# 15) Activate new root
#--------------------------------------
Echo "Activating Image: [$imageRootDevice]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -217,13 +222,14 @@
rm ./include
fi
#======================================
-# 15) Unmount initrd / system init
+# 16) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into final System..."
echo "----------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / 2>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-SLED10/config.xml new/kiwi/system/boot/vmxboot/suse-SLED10/config.xml
--- old/kiwi/system/boot/vmxboot/suse-SLED10/config.xml 2007-10-11 15:33:18.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-SLED10/config.xml 2007-10-17 16:12:54.000000000 +0200
@@ -114,7 +114,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-SLED10-SP1/config.xml new/kiwi/system/boot/vmxboot/suse-SLED10-SP1/config.xml
--- old/kiwi/system/boot/vmxboot/suse-SLED10-SP1/config.xml 2007-10-11 15:33:19.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-SLED10-SP1/config.xml 2007-10-17 16:12:55.000000000 +0200
@@ -114,7 +114,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-SLES10/config.xml new/kiwi/system/boot/vmxboot/suse-SLES10/config.xml
--- old/kiwi/system/boot/vmxboot/suse-SLES10/config.xml 2007-10-11 15:33:17.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-SLES10/config.xml 2007-10-17 16:12:52.000000000 +0200
@@ -115,7 +115,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/vmxboot/suse-SLES10-SP1/config.xml new/kiwi/system/boot/vmxboot/suse-SLES10-SP1/config.xml
--- old/kiwi/system/boot/vmxboot/suse-SLES10-SP1/config.xml 2007-10-11 15:33:18.000000000 +0200
+++ new/kiwi/system/boot/vmxboot/suse-SLES10-SP1/config.xml 2007-10-17 16:12:55.000000000 +0200
@@ -115,7 +115,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="gfxboot"/>
<package name="fribidi"/>
<package name="make"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-10.1/config.xml new/kiwi/system/boot/xenboot/suse-10.1/config.xml
--- old/kiwi/system/boot/xenboot/suse-10.1/config.xml 2007-10-11 15:33:23.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-10.1/config.xml 2007-10-17 16:13:06.000000000 +0200
@@ -109,7 +109,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="mkinitrd"/>
<package name="net-tools"/>
<package name="gfxboot"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-linuxrc new/kiwi/system/boot/xenboot/suse-linuxrc
--- old/kiwi/system/boot/xenboot/suse-linuxrc 2007-10-11 15:39:08.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-linuxrc 2007-10-17 16:13:08.000000000 +0200
@@ -63,32 +63,36 @@
touch /lib/modules/*/modules.dep
#======================================
-# 3) Including required kernel modules
+# 3) run udevd
+#--------------------------------------
+udevStart
+
+#======================================
+# 4) Including required kernel modules
#--------------------------------------
Echo "Including required kernel modules..."
for module in xennet xenblk reiserfs ext2 ext3 loop ipv6;do
modprobe $module >/dev/null 2>&1
done
-udevStart
#======================================
-# 4) Mount VM (boot)
+# 5) Mount VM (boot)
#--------------------------------------
VMMountSystem
#======================================
-# 5) Get filesystem type
+# 6) Get filesystem type
#--------------------------------------
probeFileSystem $imageRootDevice
#======================================
-# 6) Create system dependant files
+# 7) Create system dependant files
#--------------------------------------
setupDefaultFstab /config
updateRootDeviceFstab /config $imageRootDevice
#======================================
-# 7) copy system dependant files
+# 8) copy system dependant files
#--------------------------------------
cd /config
find . -type d | while read d ; do mkdir -p /mnt/$d ; done
@@ -97,29 +101,29 @@
rm -rf /config
#======================================
-# 8) setup real root device
+# 9) setup real root device
#--------------------------------------
echo 256 > /proc/sys/kernel/real-root-dev
#======================================
-# 9) umount system filesystems
+# 10) umount system filesystems
#--------------------------------------
-udevKill
umountSystemFilesystems
#======================================
-# 10) copy initrd files to image
+# 11) copy initrd files to image
#--------------------------------------
cp /preinit /mnt
cp /include /mnt
#======================================
-# 11) Activate new root
+# 12) Activate new root
#--------------------------------------
Echo "Activating Image: [$imageRootDevice]"
-mkdir -p /mnt/dev && copyDevices /mnt/dev
-cd /mnt && exec < dev/console >dev/console 2>&1
+/sbin/udevsettle --timeout=30
+mount --move /dev /mnt/dev
Echo "Calling preinit phase..."
+cd /mnt && exec < dev/console >dev/console 2>&1
reopenKernelConsole
/mnt/sbin/pivot_root . mnt >/dev/null 2>&1
if test $? != 0;then
@@ -134,13 +138,14 @@
rm ./include
fi
#======================================
-# 12) Unmount initrd / system init
+# 13) Unmount initrd / system init
#--------------------------------------
echo " "
echo "Booting into Xen System..."
echo "--------------------------"
export IFS=$IFS_ORIG
mount -n -o remount,rw / &>/dev/null
+udevKill
if [ $PIVOT = "true" ];then
exec umount -n -l /mnt
else
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-SLED10/config.xml new/kiwi/system/boot/xenboot/suse-SLED10/config.xml
--- old/kiwi/system/boot/xenboot/suse-SLED10/config.xml 2007-10-11 15:33:21.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-SLED10/config.xml 2007-10-17 16:13:02.000000000 +0200
@@ -111,7 +111,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="mkinitrd"/>
<package name="net-tools"/>
<package name="gfxboot"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-SLED10-SP1/config.xml new/kiwi/system/boot/xenboot/suse-SLED10-SP1/config.xml
--- old/kiwi/system/boot/xenboot/suse-SLED10-SP1/config.xml 2007-10-11 15:33:22.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-SLED10-SP1/config.xml 2007-10-17 16:13:05.000000000 +0200
@@ -111,7 +111,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="mkinitrd"/>
<package name="net-tools"/>
<package name="gfxboot"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-SLES10/config.xml new/kiwi/system/boot/xenboot/suse-SLES10/config.xml
--- old/kiwi/system/boot/xenboot/suse-SLES10/config.xml 2007-10-11 15:33:21.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-SLES10/config.xml 2007-10-17 16:13:01.000000000 +0200
@@ -111,7 +111,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="mkinitrd"/>
<package name="net-tools"/>
<package name="gfxboot"/>
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/system/boot/xenboot/suse-SLES10-SP1/config.xml new/kiwi/system/boot/xenboot/suse-SLES10-SP1/config.xml
--- old/kiwi/system/boot/xenboot/suse-SLES10-SP1/config.xml 2007-10-11 15:33:22.000000000 +0200
+++ new/kiwi/system/boot/xenboot/suse-SLES10-SP1/config.xml 2007-10-17 16:13:03.000000000 +0200
@@ -111,7 +111,6 @@
<package name="rpm-python"/>
<package name="smart"/>
<package name="suse-build-key"/>
- <package name="udev"/>
<package name="mkinitrd"/>
<package name="net-tools"/>
<package name="gfxboot"/>
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Remember to have fun...
---------------------------------------------------------------------
To unsubscribe, e-mail: opensuse-commit+unsubscribe@xxxxxxxxxxxx
For additional commands, e-mail: opensuse-commit+help@xxxxxxxxxxxx
| < Previous | Next > |
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/kiwi/modules/KIWILinuxRC.sh new/kiwi/modules/KIWILinuxRC.sh
--- old/kiwi/modules/KIWILinuxRC.sh 2007-10-11 15:39:09.000000000 +0200
+++ new/kiwi/modules/KIWILinuxRC.sh 2007-10-17 16:13:13.000000000 +0200
@@ -140,9 +140,9 @@
#======================================
# copyDevices
#--------------------------------------
-function copyDevices {
- local prefix=$1
- local search=$2
+function copyDeviceNodes {
+ local search=$1
+ local prefix=$2
local dtype
local major
local minor
@@ -177,37 +177,51 @@
popd >/dev/null 2>&1
}
#======================================
+# copyDevices
+#--------------------------------------
+function createInitialDevices {
+ local prefix=$1
+ mkdir -p $prefix
+ if [ ! -d $prefix ];then
+ return
+ fi
+ if [ -e $prefix/null ];then
+ rm -f $prefix/null
+ fi
+ test -c $prefix/tty || mknod -m 0666 $prefix/tty c 5 0
+ test -c $prefix/console || mknod -m 0600 $prefix/console c 5 1
+ test -c $prefix/ptmx || mknod -m 0666 $prefix/ptmx c 5 2
+ exec < $prefix/console > $prefix/console 2>&1
+ test -c $prefix/null || mknod -m 0666 $prefix/null c 1 3
+ test -c $prefix/kmsg || mknod -m 0600 $prefix/kmsg c 1 11
+ test -c $prefix/snapshot || mknod -m 0660 $prefix/snapshot c 10 231
+ test -c $prefix/random || mknod -m 0666 $prefix/random c 1 8
+ test -c $prefix/urandom || mknod -m 0644 $prefix/urandom c 1 9
+ test -b $prefix/loop0 || mknod -m 0640 $prefix/loop0 b 7 0
+ test -b $prefix/loop1 || mknod -m 0640 $prefix/loop1 b 7 1
+ test -b $prefix/loop2 || mknod -m 0640 $prefix/loop2 b 7 2
+ mkdir -p -m 0755 $prefix/pts
+ mkdir -p -m 1777 $prefix/shm
+ test -L $prefix/fd || ln -s /proc/self/fd $prefix/fd
+ test -L $prefix/stdin || ln -s fd/0 $prefix/stdin
+ test -L $prefix/stdout || ln -s fd/1 $prefix/stdout
+ test -L $prefix/stderr || ln -s fd/2 $prefix/stderr
+}
+#======================================
# mountSystemFilesystems
#--------------------------------------
function mountSystemFilesystems {
- mount -t proc proc /proc &>/dev/null
- mount -t sysfs sysfs /sys &>/dev/null
- mount -t tmpfs -o mode=0755 udev /dev &>/dev/null
- mount -t devpts devpts /dev/pts &>/dev/null
- mknod -m 0640 /dev/loop0 b 7 0
- mknod -m 0640 /dev/loop1 b 7 1
- mknod -m 0640 /dev/loop2 b 7 2
- mknod -m 0666 /dev/tty c 5 0
- mknod -m 0600 /dev/console c 5 1
- mknod -m 0666 /dev/ptmx c 5 2
- mknod -m 0666 /dev/null c 1 3
- mknod -m 0600 /dev/kmsg c 1 11
- mknod -m 0660 /dev/snapshot c 10 231
- mknod -m 0666 /dev/random c 1 8
- mknod -m 0644 /dev/urandom c 1 9
- mkdir -m 0755 /dev/pts
- mkdir -m 1777 /dev/shm
- ln -s /proc/self/fd /dev/fd
- ln -s fd/0 /dev/stdin
- ln -s fd/1 /dev/stdout
- ln -s fd/2 /dev/stderr
+ mount -t proc proc /proc
+ mount -t sysfs sysfs /sys
+ mount -t tmpfs -o mode=0755 udev /dev
+ createInitialDevices /dev
+ mount -t devpts devpts /dev/pts
}
#======================================
# umountSystemFilesystems
#--------------------------------------
function umountSystemFilesystems {
umount /dev/pts &>/dev/null
- umount /dev &>/dev/null
umount /sys &>/dev/null
umount /proc &>/dev/null
}
@@ -232,9 +246,9 @@
# disable hotplug helper, udevd listens to netlink
echo "" > /proc/sys/kernel/hotplug
# create min devices
- copyDevices /dev /lib/udev/devices
+ copyDeviceNodes /lib/udev/devices /dev
# start udevd
- udevd --daemon
+ udevd --daemon udev_log="debug"
# cleanup some stuff
rm -f /var/run/sysconfig/network
# unlikely, but we may be faster than the first event
@@ -242,14 +256,15 @@
mkdir -p /dev/.udev/queue
# create devices
/sbin/udevtrigger
- # 10 min - just long enough
- /sbin/udevsettle --timeout=600
+ # 30 sec - just long enough
+ /sbin/udevsettle --timeout=30
+ udevPID=`/sbin/pidof udevd`
}
#======================================
# udevKill
#--------------------------------------
function udevKill {
- kill $(/sbin/pidof udevd)
+ kill $udevPID
}
#======================================
# installGrub
@@ -279,9 +294,21 @@
# based on /etc/sysconfig/kernel
# ----
grubOK=1
- if [ -f /boot/System.map* ];then
- mount -t proc proc /proc
- mount -t sysfs sysfs /sys
+ local umountProc=0
+ local umountSys=0
+ local systemMap=0
+ for i in /boot/System.map*;do
+ systemMap=1
+ done
+ if [ $systemMap -eq 1 ];then
+ if [ ! -e /proc/mounts ];then
+ mount -t proc proc /proc
+ umountProc=1
+ fi
+ if [ ! -e /sys/block ];then
+ mount -t sysfs sysfs /sys
+ umountSys=1
+ fi
if [ -f /etc/init.d/boot.device-mapper ];then
/etc/init.d/boot.device-mapper start
fi
@@ -289,8 +316,12 @@
if [ -f /etc/init.d/boot.device-mapper ];then
/etc/init.d/boot.device-mapper stop
fi
- umount /sys
- umount /proc
+ if [ $umountSys -eq 1 ];then
+ umount /sys
+ fi
+ if [ $umountProc -eq 1 ];then
+ umount /proc
+ fi
else
Echo "Image doesn't include kernel system map"
Echo "Can't create initrd"
@@ -707,16 +738,26 @@
# detect CD/DVD device. The function use the information
# from hwinfo --cdrom to activate the drive
# ----
+ local count=0
for module in usb-storage sr_mod cdrom ide-cd BusLogic;do
/sbin/modprobe $module
done
- cddevs=`/usr/sbin/hwinfo --cdrom | grep "Device File:" | cut -f2 -d:`
- for i in $cddevs;do
- if [ -b $i ];then
- test -z $cddev && cddev=$i || cddev=$cddev:$i
+ while true;do
+ cddevs=`/usr/sbin/hwinfo --cdrom | grep "Device File:" | cut -f2 -d:`
+ for i in $cddevs;do
+ if [ -b $i ];then
+ test -z $cddev && cddev=$i || cddev=$cddev:$i
+ fi
+ done
+ if [ ! -z $cddev ] || [ $count -eq 4 ]; then
+ break
+ else
+ Echo "Drive not ready yet... waiting"
+ sleep 1
fi
+ count=`expr $count + 1`
done
- if [ -z $cddev ]; then
+ if [ -z $cddev ];then
systemException \
"Failed to detect CD drive !" \
"reboot"
@@ -848,7 +889,7 @@
umount=1
fi
cat /proc/mounts > $prefix/etc/mtab
- if [ $umount = 1 ];then
+ if [ $umount -eq 1 ];then
umount /proc
fi
}